==> dotykacka-java-api-client-0.1.0-sources.jar: pl/grizzlysoftware/dotykacka/client/v1/api/util/DotykackaServiceContextPath.java <==
/*
 * Copyright 2019 Grizzly Software, https://grizzlysoftware.pl
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package pl.grizzlysoftware.dotykacka.client.v1.api.util;

/**
 * @author Bartosz Pawłowski, bpawlowski@grizzlysoftware.pl
 */
public interface DotykackaServiceContextPath {
    String OAUTH = "/oauth";
    String PRODUCT = "/api/product";
    String CUSTOMER = "/api/customer";

    interface SALES {
        String SALES = "/api/sales";
        String RECEIPT = "/api/receipt";
        String ORDER = "/api/order";
        String ORDER_OPEN = "/api/order-open";
        String MONEYLOG = "/api/moneylog";
    }
}

==> dotykacka-java-api-client-0.2.1-sources.jar: pl/grizzlysoftware/dotykacka/client/v1/api/util/DotykackaServiceContextPath.java <==
/*
 * Copyright 2019 Grizzly Software, https://grizzlysoftware.pl
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package pl.grizzlysoftware.dotykacka.client.v1.api.util;

/**
 * @author Bartosz Pawłowski, bpawlowski@grizzlysoftware.pl
 */
public interface DotykackaServiceContextPath {
    String OAUTH = "/oauth";
    String PRODUCT = "/api/product";
    String CUSTOMER = "/api/customer";
    String BRANCH = "/api/branches";
    String CATEGORY = "/api/category";
    String EMPLOYEE = "/api/employee";
    String SUPPLIER = "/api/supplier";
    String WAREHOUSE = "/api/warehouse";
    String TAG = "/api/tag";
    String TABLESEAT = "/api/tableseat";

    interface SALES {
        String SALES = "/api/sales";
        String RECEIPT = "/api/receipt";
        String ORDER = "/api/order";
        String ORDER_OPEN = "/api/order-open";
        String MONEYLOG = "/api/moneylog";
    }
}
